Package: rfaRm
Type: Package
Title: An R interface to the Rfam database
Version: 1.25.1
Date: 2026-06-10
Author: Lara Selles Vidal, Rafael Ayala, Guy-Bart Stan, Rodrigo Ledesma-Amaro
Maintainer: Lara Selles Vidal <lara.selles@oist.jp>,
 Rafael Ayala <rafael.ayala@oist.jp>
Description: rfaRm provides a client interface to the Rfam database of RNA 
    families. Data that can be retrieved include RNA families, secondary 
    structure images, covariance models, sequences within each family,
    alignments leading to the identification of a family and secondary 
    structures in the dot-bracket format.
License: GPL-3
Imports: httr, stringi, rsvg, magick, data.table, Biostrings, utils,
        rvest, xml2, IRanges, S4Vectors
Suggests: R4RNA, treeio, knitr, BiocStyle, rmarkdown, BiocGenerics,
        RUnit
VignetteBuilder: knitr
biocViews: FunctionalGenomics, DataImport, ThirdPartyClient,
        Visualization, MultipleSequenceAlignment
NeedsCompilation: no
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/rfaRm
git_branch: devel
git_last_commit: ac979b2
git_last_commit_date: 2026-06-09
Repository: Bioconductor 3.24
Date/Publication: 2026-07-09
Packaged: 2026-07-09 22:39:28 UTC; biocbuild
Built: R 4.6.1; ; 2026-07-10 06:05:13 UTC; unix
