export('rfamTextSearchFamilyAccession')
export('rfamFamilyAccessionToID')
export('rfamFamilyIDToAccession')
export('rfamFamilySummary')
export('rfamSecondaryStructureXMLSVG')
export('rfamSecondaryStructurePlot')
export('rfamCovarianceModel')
export('rfamSequenceRegions')
export('rfamSeedTree')
export('rfamSeedTreeImage')
export('rfamPDBMapping')
export('rfamSeedAlignment')
export('rfamConsensusSecondaryStructure')
export('rfamSequenceSearch')
import('httr')
import('data.table')
import('Biostrings')
import('rvest')
import('xml2')
import('IRanges', except=shift)
importFrom("S4Vectors", queryHits, subjectHits)
importFrom('rsvg', rsvg)
importFrom('stringi', stri_split_lines)
importFrom("magick", image_read, image_write)
importFrom("utils", read.delim, write.table)

